==> tabular-data-mainbox-widget-1.0.0-3.5.0.jar: org/gcube/portlets/user/td/mainboxwidget/client/resources/MainboxResources.java <==
/**
 * 
 */
package org.gcube.portlets.user.td.mainboxwidget.client.resources;

import com.google.gwt.core.client.GWT;
import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.ImageResource;


/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 *
 */
public interface MainboxResources extends ClientBundle {

	public static final MainboxResources INSTANCE = GWT
			.create(MainboxResources.class);

	@Source("column-type_32.png")
	ImageResource columnType32();

	@Source("column-type.png")
	ImageResource columnType();

	@Source("column-label_32.png")
	ImageResource columnLabel32();

	@Source("column-label.png")
	ImageResource columnLabel();

	@Source("column-filter_32.png")
	ImageResource columnFilter32();

	@Source("column-filter.png")
	ImageResource columnFilter();

	@Source("column-edit_32.png")
	ImageResource columnEdit32();

	@Source("column-edit.png")
	ImageResource columnEdit();

	@Source("column-delete_32.png")
	ImageResource columnDelete32();

	@Source("column-delete.png")
	ImageResource columnDelete();

	@Source("column-add_32.png")
	ImageResource columnAdd32();

	@Source("column-add.png")
	ImageResource columnAdd();

	@Source("column-replace.png")
	ImageResource columnReplace();

	@Source("column-replace_32.png")
	ImageResource columnReplace32();

	@Source("column-replace-batch.png")
	ImageResource columnReplaceBatch();

	@Source("column-replace-batch_32.png")
	ImageResource columnReplaceBatch32();

	@Source("pencil_32.png")
	ImageResource rowEdit32();

	@Source("pencil.png")
	ImageResource rowEdit();

	@Source("table-row-insert_32.png")
	ImageResource rowInsert32();

	@Source("table-row-insert.png")
	ImageResource rowInsert();

	@Source("table-row-delete_32.png")
	ImageResource rowRemove32();

	@Source("table-row-delete.png")
	ImageResource rowRemove();

	@Source("column-split_32.png")
	ImageResource columnSplit32();

	@Source("column-split.png")
	ImageResource columnSplit();

	@Source("column-merge_32.png")
	ImageResource columnMerge32();

	@Source("column-merge.png")
	ImageResource columnMerge();

	@Source("column-replace-by-expression_32.png")
	ImageResource columnReplaceByExpression32();

	@Source("column-replace-by-expression.png")
	ImageResource columnReplaceByExpression();

	@Source("page-white_32.png")
	ImageResource tabularResource32();

	@Source("page-white.png")
	ImageResource tabularResource();
	
}

==> tabular-data-mainbox-widget-1.0.0-20150113.102943-88.jar: org/gcube/portlets/user/td/mainboxwidget/client/resources/MainboxResources.java <==
/**
 * 
 */
package org.gcube.portlets.user.td.mainboxwidget.client.resources;

import com.google.gwt.core.client.GWT;
import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.ImageResource;


/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 *
 */
public interface MainboxResources extends ClientBundle {

	public static final MainboxResources INSTANCE = GWT
			.create(MainboxResources.class);

	@Source("column-type_32.png")
	ImageResource columnType32();

	@Source("column-type.png")
	ImageResource columnType();

	@Source("column-label_32.png")
	ImageResource columnLabel32();

	@Source("column-label.png")
	ImageResource columnLabel();

	@Source("column-filter_32.png")
	ImageResource columnFilter32();

	@Source("column-filter.png")
	ImageResource columnFilter();

	@Source("column-edit_32.png")
	ImageResource columnEdit32();

	@Source("column-edit.png")
	ImageResource columnEdit();

	@Source("column-delete_32.png")
	ImageResource columnDelete32();

	@Source("column-delete.png")
	ImageResource columnDelete();

	@Source("column-add_32.png")
	ImageResource columnAdd32();

	@Source("column-add.png")
	ImageResource columnAdd();

	@Source("column-replace.png")
	ImageResource columnReplace();

	@Source("column-replace_32.png")
	ImageResource columnReplace32();

	@Source("column-replace-batch.png")
	ImageResource columnReplaceBatch();

	@Source("column-replace-batch_32.png")
	ImageResource columnReplaceBatch32();

	@Source("pencil_32.png")
	ImageResource rowEdit32();

	@Source("pencil.png")
	ImageResource rowEdit();

	@Source("table-row-insert_32.png")
	ImageResource rowInsert32();

	@Source("table-row-insert.png")
	ImageResource rowInsert();

	@Source("table-row-delete_32.png")
	ImageResource rowRemove32();

	@Source("table-row-delete.png")
	ImageResource rowRemove();

	@Source("column-split_32.png")
	ImageResource columnSplit32();

	@Source("column-split.png")
	ImageResource columnSplit();

	@Source("column-merge_32.png")
	ImageResource columnMerge32();

	@Source("column-merge.png")
	ImageResource columnMerge();

	@Source("column-replace-by-expression_32.png")
	ImageResource columnReplaceByExpression32();

	@Source("column-replace-by-expression.png")
	ImageResource columnReplaceByExpression();

	@Source("page-white_32.png")
	ImageResource tabularResource32();

	@Source("page-white.png")
	ImageResource tabularResource();
	
	@Source("table-replace-by-external-col_32.png")
	ImageResource columnReplaceByExternal32();

	@Source("table-replace-by-external-col.png")
	ImageResource columnReplaceByExternal();

	
	
	
}
